@@ -17,13 +17,13 @@
 
 package org.apache.seatunnel.spark;
 
-import static org.apache.seatunnel.plugin.Plugin.RESULT_TABLE_NAME;
-import static org.apache.seatunnel.plugin.Plugin.SOURCE_TABLE_NAME;
+import static org.apache.seatunnel.apis.base.plugin.Plugin.RESULT_TABLE_NAME;
+import static org.apache.seatunnel.apis.base.plugin.Plugin.SOURCE_TABLE_NAME;
 
+import org.apache.seatunnel.apis.base.env.RuntimeEnv;
 import org.apache.seatunnel.common.config.CheckResult;
 import org.apache.seatunnel.common.config.ConfigRuntimeException;
 import org.apache.seatunnel.common.constants.JobMode;
-import org.apache.seatunnel.env.RuntimeEnv;
 
 import org.apache.seatunnel.shade.com.typesafe.config.Config;
 import org.apache.seatunnel.shade.com.typesafe.config.ConfigFactory;
@@ -34,9 +34,16 @@ import org.apache.spark.sql.Row;
 import org.apache.spark.sql.SparkSession;
 import org.apache.spark.streaming.Seconds;
 import org.apache.spark.streaming.StreamingContext;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
+import java.net.URL;
+import java.util.List;
 
 public class SparkEnvironment implements RuntimeEnv {
 
+    private static final Logger LOGGER = LoggerFactory.getLogger(SparkEnvironment.class);
+
     private static final long DEFAULT_SPARK_STREAMING_DURATION = 5;
 
     private SparkSession sparkSession;
@@ -81,6 +88,14 @@ public class SparkEnvironment implements RuntimeEnv {
         return CheckResult.success();
     }
 
+    @Override
+    public void registerPlugin(List<URL> pluginPaths) {
+        LOGGER.info("register plugins :" + pluginPaths);
+        // TODO we use --jar parameter to support submit multi-jar in spark cluster at now. Refactor it to
+        //  support submit multi-jar in code or remove this logic.
+        // this.sparkSession.conf().set("spark.jars",pluginPaths.stream().map(URL::getPath).collect(Collectors.joining(",")));
+    }
+
     @Override
     public SparkEnvironment prepare() {
         SparkConf sparkConf = createSparkConf();
@@ -152,7 +167,7 @@ public class SparkEnvironment implements RuntimeEnv {
         }
     }
 
-    public  static <T extends Object> T sinkProcess(SparkEnvironment environment, BaseSparkSink<T> sink, Dataset<Row> ds) {
+    public static <T extends Object> T sinkProcess(SparkEnvironment environment, BaseSparkSink<T> sink, Dataset<Row> ds) {
         Dataset<Row> fromDs;
         Config config = sink.getConfig();
         if (config.hasPath(SOURCE_TABLE_NAME)) {
